Spatio-Temporal Metrics
=====================================

.. image:: https://readthedocs.org/projects/stmetrics/badge/?version=latest
		:target: https://stmetrics.readthedocs.io/en/latest/?badge=latest
		:alt: Documentation Status

.. image:: https://img.shields.io/badge/license-MIT-green
        :target: https://github.com/andersonreisoares/stmetrics/master/LICENSE
        :alt: License

Produce reliable land use and land cover maps to support the deployment and operation of public policies is a necessity, especially when environmental management and economic development are considered. To increase the accuracy of these maps, satellite image time-series have been used, as they allow the understanding of land cover dynamics through the time.

The stmetrics, is a python package that provides the extraction of state-of-the-art time-series features. These features can be used for remote sensing time-series image classification and analysis.

Installation
=============
You can pip install it straight from git:

.. code-block:: console

	pip install stmetrics	

For windows users:
==================
  Please before installing the package make sure that you have correctly installed the Shapely package.
  
Using conda do this:
---------------------

.. code-block:: python

	conda config --add channels conda-forge
	conda install shapely

Developer Documentation
========================
See https://stmetrics.readthedocs.io/en/latest/


Collaborators
=============

- Thales Körting
- Hugo Bendini
- Leila Fonseca
- Daiane Vaz
- Tatiana Uehara
- Michel Chaves
- Sarah Lechler
